# v0.0.2

## New

- JSON-RPC handler with OpenAPI spec generation and HTML documentation (`woodglue.jsonrpc`)
- Server factory and CLI integration for JSON-RPC services
- CLI argument parsing for function arguments (`woodglue.cli`)
- Periodic task scheduling support

## Changed

- Refactored logic that moved to `lythonic` into a cleaner separation
- Removed auto-discovery module in favor of explicit registration
- Cleaned up lint issues across the codebase
- Synced dev configuration from `lythonic`

## Fixes

- Consolidated tests and fixed subtle bug in test infrastructure
- Fixed Windows test compatibility issue
- Fixed lint errors in JSON-RPC modules

## Documentation

- Added JSON-RPC usage documentation and execution report
- Added MillFarm spec
